/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.register.managedbean;

import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;
import javax.inject.Named;

import org.defne.owb.bindings.PojoExecutorProxy;
import org.defne.register.service.IRegisterService;
import org.defne.service.IMessageConstants;
import org.defne.service.Message;
import org.defne.service.MessageFactory;
import org.defne.service.TransactionPolicy;
import org.defne.service.executor.IServiceExecutorProxy;

@Named
@RequestScoped
public class RegisterBean {

    private @Inject @PojoExecutorProxy IServiceExecutorProxy pojoExecutor;
    
    private String message;
    
    private String name;
    
    private String surname;
    
    private String id;
    
    public RegisterBean()
    {
	
    }
    
    public String register()
    {
        //Creating a message
        Message input = MessageFactory.newMessage(IRegisterService.SERVICE_NAME,IRegisterService.RegisterOperation.OPERATION_NAME);
        
        //Calling with JPA transaction
        input.putMessageParameter(IMessageConstants.SERVICE_CALLER_TRANSACTION_POLICY, TransactionPolicy.WITH_TRANSACTION);
        
        //Adding service parameters
        input.putMessageParameter(IRegisterService.RegisterOperation.INPUT.NAME, this.name);        
        input.putMessageParameter(IRegisterService.RegisterOperation.INPUT.SURNAME, this.surname);
        
        //Execute servcie
        input = this.pojoExecutor.execute(input);
        
        //Any message
        this.message = input.getMessageParameter(String.class, IRegisterService.RegisterOperation.OUTPUT.MESSAGE);     
        Integer valId = input.getMessageParameter(Integer.class, IRegisterService.RegisterOperation.OUTPUT.ID);
        this.id = valId.toString();
        
        return null;
        
    }
    
    public String update()
    {
        //Creating a message
        Message input = MessageFactory.newMessage(IRegisterService.SERVICE_NAME,IRegisterService.UpdateOperation.OPERATION_NAME);
        
        //Adding service parameters
        input.putMessageParameter(IRegisterService.UpdateOperation.INPUT.NAME, this.name);        
        input.putMessageParameter(IRegisterService.UpdateOperation.INPUT.SURNAME, this.surname);
        input.putMessageParameter(IRegisterService.UpdateOperation.INPUT.ID, Integer.parseInt(this.id));
        
        //Execute servcie
        input = this.pojoExecutor.execute(input);
        
        //Any message
        this.message = input.getMessageParameter(String.class, IRegisterService.UpdateOperation.OUTPUT.MESSAGE);     

        return null;
        
    }
    
    
    public String getMessage()
    {
        return message;
    }

    public void setMessage(String message)
    {
        this.message = message;
    }

    public String getName()
    {
        return name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    public String getSurname()
    {
        return surname;
    }

    public void setSurname(String surname)
    {
        this.surname = surname;
    }

    public String getId()
    {
        return id;
    }

    public void setId(String id)
    {
        this.id = id;
    }
    
    
}
