/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.defne.register.service;

import javax.persistence.EntityManager;
import javax.persistence.Query;

import org.defne.jpa.EntityManagerUtil;
import org.defne.register.entity.Person;
import org.defne.service.Message;
import org.defne.service.TransactionPolicy;
import org.defne.service.annotation.EntityManagerAttribute;
import org.defne.service.annotation.Operation;
import org.defne.service.annotation.Service;
import org.defne.service.annotation.TransactionAttribute;
import org.defne.utility.exception.DefneException;

@Service
public class RegisterService
{
    @Operation
    public static Message register(Message inBag) throws DefneException
    {
        String name = inBag.getMessageParameter(String.class, IRegisterService.RegisterOperation.INPUT.NAME);
        String surname = inBag.getMessageParameter(String.class, IRegisterService.RegisterOperation.INPUT.SURNAME);
        
        EntityManager entityManager = EntityManagerUtil.getEntityManagerFromBag(inBag);
        
        Person person = new Person();
        person.setName(name);
        person.setSurname(surname);
        
        entityManager.persist(person);
        
        inBag.putMessageParameter(IRegisterService.RegisterOperation.OUTPUT.ID, person.getId());
        inBag.putMessageParameter(IRegisterService.RegisterOperation.OUTPUT.MESSAGE, "Registered user, " + 
                name + surname + " with ID = " + Integer.toString(person.getId()));
                
        return inBag;
    }
    
    @Operation
    @TransactionAttribute(TransactionPolicy.WITH_TRANSACTION)
    @EntityManagerAttribute(use=true)
    public static Message update(Message inBag) throws DefneException
    {
        String name = inBag.getMessageParameter(String.class, IRegisterService.UpdateOperation.INPUT.NAME);
        String surname = inBag.getMessageParameter(String.class, IRegisterService.UpdateOperation.INPUT.SURNAME);
        Integer id = inBag.getMessageParameter(Integer.class, IRegisterService.UpdateOperation.INPUT.ID);
        
        EntityManager entityManager = EntityManagerUtil.getEntityManagerFromBag(inBag);
        Query query = entityManager.createQuery("select p from Person p where p.id=:id");
        query.setParameter("id", id);
        
        Person p = (Person) query.getSingleResult();
        
        p.setName(name);
        p.setSurname(surname);
        
        inBag.putMessageParameter(IRegisterService.UpdateOperation.OUTPUT.MESSAGE, "Updated user, " + 
                name + surname + " with ID = " + Integer.toString(p.getId()));
                
        return inBag;
        
    }
        
}
